@@ -1,5 +1,5 @@
 /* mp4h -- A macro processor for HTML documents
-   Copyright 2000, Denis Barbier
+   Copyright 2000-2001, Denis Barbier
    All rights reserved.
 
    This program is free software; you can redistribute it and/or modify
@@ -766,5 +766,5 @@ expand_unknown_tag (char *name, read_type expansion)
   obstack_free (&argptr, NULL);
   obstack_free (&body, NULL);
 
-  xfree (symbol_name);
+  xfree ((voidstar) symbol_name);
 }
