@@ -1,5 +1,5 @@
 /* mp4h -- A macro processor for HTML documents
-   Copyright 2000, Denis Barbier
+   Copyright 2000-2001, Denis Barbier
    All rights reserved.
 
    This program is free software; you can redistribute it and/or modify
@@ -37,11 +37,7 @@
 
 #include <sys/types.h>
 
-#if __STDC__
 # define voidstar void *
-#else
-# define voidstar char *
-#endif
 
 #include <stdio.h>
 #include <ctype.h>
@@ -150,8 +146,8 @@ struct string
 typedef struct string STRING;
 
 /* Memory allocation.  */
-voidstar xmalloc __P ((unsigned int));
-voidstar xrealloc __P ((voidstar , unsigned int));
+voidstar xmalloc __P ((size_t));
+voidstar xrealloc __P ((voidstar , size_t));
 void xfree __P ((voidstar));
 char *xstrdup __P ((const char *));
 #define obstack_chunk_alloc     xmalloc
@@ -547,6 +543,13 @@ extern int expansion_level;
 
 /* File: builtin.c  --- builtins.  */
 
+enum encoding_type
+{
+  ENCODING_8BIT,                /* 1-byte char */
+  ENCODING_UTF8                 /* UTF-8 */
+};
+typedef enum encoding_type encoding_type;
+
 struct builtin
 {
   const char *name;
@@ -559,6 +562,12 @@ typedef struct builtin builtin;
 
 extern boolean visible_quotes;
 
+/* Used to disable risky functions. */
+extern int safety_level;
+
+/* Document encoding */
+extern encoding_type document_encoding;
+
 void locale_init __P ((void));
 void initialize_builtin __P ((symbol *));
 void builtin_init __P ((void));
@@ -642,13 +651,14 @@ void reload_frozen_state __P ((const char *));
 
 /* File: module.c --- dynamic modules */
 
-#ifdef WITH_MODULES
+#if defined(WITH_MODULES) || defined(MP4H_MODULE)
 
 typedef void module_init_t __P ((struct obstack *));
 typedef void module_finish_t __P ((void));
 
 typedef voidstar module_func __P ((const char *));
 
+void library_load __P ((const char *, struct obstack *));
 void module_load __P ((const char *, struct obstack *));
 void module_unload_all __P ((void));
 
